"""
NCCA2020; Nested for loops; UI; ALT2; Image Manipulation;

This program takes an image (imageFileName) as its input.
Creates a copy of the original.
It loops through every pixel in the image, and detects signifcant differences in colour.
This is considered an Edge Detection.
The mean of the RedGreenBlue values are used to measure each pixel's colour strength.
The original and edge detected pictures are stored in a new file.
The name of the new file is based on the original filename, in the same location as the original.
"""

# The Processing Image Library is installed from the PILLOW library (a fork of PIL)
# You must have access to this library into your IDE to avail of Image Processing functions.
from PIL import Image

#imports for using online images directly
#import requests
#from io import BytesIO

#the image will be condensed to thumbnail
tumnailWidth = 500
tumnailHeight = 500

# set the cut off value between neighbouring pixels
pixelDiffSetting = int(input("Please enter the setting (1, 2, 3) for detecting edges : \t"))
pixelDifference = 2 * pixelDiffSetting
print("pixel difference", pixelDifference)

"""
Create an image object we can work with locally from your own device.
This is much easier to do starting off and is recommended.
OR you can open an online image which follows this section.
"""
#imageFileName = "round towers.jpg"
#imageFileName = "London Bridge.jpg"
# 
imageFileName = "rabbits.jpg"
originalImage = Image.open(imageFileName)

"""
# These lines of code will open an online image.
# This requires you to import requests and IO, as is done above
imageFileName = "rabbits.jpg"
response = requests.get("https://upload.wikimedia.org/wikipedia/commons/3/37/Oryctolagus_cuniculus_Tasmania_2.jpg")
originalImage = Image.open(BytesIO(response.content))
"""

img = originalImage.copy()
#some dimensions, mainly for debugging purposes
print("img size", img.size)
print("img get pixel", img.getpixel((100,100)))
print("image width", img.size[0])
print("image height", img.size[1])

width = img.size[0]
height = img.size[1]
edgePix = img.load()

for row in range(width-1) :
    for col in range(height-1) :
        firstPixel = edgePix[row, col]
        #find the average of the RGB values
        firstPixelValue = float((firstPixel[0] + firstPixel[1] + firstPixel[2]) / 3)
        secondPixel = edgePix[row, col + 1]
        #find the average of the RGB values
        secondPixelValue = float((secondPixel[0] + secondPixel[1] + secondPixel[2]) / 3)
        #print("second pix val", secondPixelValue)

        if abs(firstPixelValue - secondPixelValue) > pixelDifference :
            #print("first pix", firstPixelValue, "second pix", secondPixelValue)
            edgePix[row, col] = (0, 0, 0)
        else :
            edgePix[row, col] = (255, 255, 255)
    

originalImage = originalImage.resize((tumnailWidth, tumnailHeight))
print("tumnail size - orig", originalImage.size)


img = img.resize((tumnailWidth, tumnailHeight))
print("tumnail size - sketch", img.size)
#img = img.crop((0, 0, 127, 127))

#img.show()
newimg = Image.new("RGB", (1000,1000))

#print("newimg pixel", newimg.getpixel((200, 100)))
# place original and sketch side by side
newimg.paste(originalImage, (0,0))
newimg.paste(img, (tumnailWidth,0))

#show and save the side by side image
newimg.show()
#assumes a 3 letter fileTypeID... easily enhanced to handle any length. 
fileTypeID = imageFileName [-4:]
imageFileNameNew = imageFileName[0:-4] + " sketch" + fileTypeID
print(imageFileNameNew)

#save the new side by side images locally
newimg.save(imageFileNameNew)
#img.show()

